(sec_citation)=

# Citing msprime

If you use `msprime` in your work, please cite the
[2022 Genetics paper](<https://doi.org/10.1093/genetics/iyab229>)
marking the 1.0 release:

> Franz Baumdicker, Gertjan Bisschop, Daniel Goldstein, Graham Gower,
> Aaron P Ragsdale, Georgia Tsambos, Sha Zhu, Bjarki Eldon, E Castedo Ellerman,
> Jared G Galloway, Ariella L Gladstein, Gregor Gorjanc, Bing Guo,
> Ben Jeffery, Warren W Kretzschumar, Konrad Lohse, Michael Matschiner,
> Dominic Nelson, Nathaniel S Pope, Consuelo D Quinto-Cortés,
> Murillo F Rodrigues, Kumar Saunack, Thibaut Sellinger, Kevin Thornton,
> Hugo van Kemenade, Anthony W Wohns, Yan Wong, Simon Gravel, Andrew D Kern,
> Jere Koskela, Peter L Ralph and Jerome Kelleher (2022),
> *Efficient ancestry and mutation simulation with msprime 1.0*,
> Genetics, Volume 220, Issue 3. http://doi.org/10.1093/genetics/iyab229

You may also wish to cite the original
[2016 PLOS Computational Biology paper](<http://dx.doi.org/10.1371/journal.pcbi.1004842>):

> Jerome Kelleher, Alison M Etheridge and Gilean McVean (2016),
> *Efficient Coalescent Simulation and Genealogical Analysis for Large Sample Sizes*,
> PLOS Comput Biol 12(5): e1004842. doi: 10.1371/journal.pcbi.1004842

If you use the Discrete Time Wright Fisher model, please cite the
[2020 PLOS Genetics paper](https://doi.org/10.1371/journal.pgen.1008619):

> Dominic Nelson, Jerome Kelleher, Aaron P. Ragsdale, Claudia Moreau,
> Gil McVean and Simon Gravel (2020),
> *Accounting for long-range correlations in genome-wide simulations of large cohorts*,
> PLOS Genetics 16(5): e1008619. https://doi.org/10.1371/journal.pgen.1008619

If you use the FixedPedigree model, please cite the 
[2023 Science paper](https://doi.org/10.1126/science.add5300):

> Luke Anderson-Trocmé et al. (2023),  *On the genes, genealogies, and geographies of Quebec*,
> Science 380.6647 (2023): 849-855. https://doi.org/10.1126/science.add5300

Bibtex records:

```bibtex

@article{baumdicker2022efficient,
  title={Efficient ancestry and mutation simulation with msprime 1.0},
  author = {Baumdicker, Franz and Bisschop, Gertjan and Goldstein, Daniel
    and Gower, Graham and Ragsdale, Aaron P and Tsambos, Georgia and Zhu, Sha
    and Eldon, Bjarki and Ellerman, E Castedo and Galloway, Jared G
    and Gladstein, Ariella L and Gorjanc, Gregor and Guo, Bing
    and Jeffery, Ben and Kretzschumar, Warren W and Lohse, Konrad
    and Matschiner, Michael and Nelson, Dominic and Pope, Nathaniel S
    and Quinto-Cortés, Consuelo D and Rodrigues, Murillo F
    and Saunack, Kumar and Sellinger, Thibaut and Thornton, Kevin
    and van Kemenade, Hugo and Wohns, Anthony W and Wong, Yan
    and Gravel, Simon and Kern, Andrew D and Koskela, Jere
    and Ralph, Peter L and Kelleher, Jerome},
  journal={Genetics},
  volume={220},
  number={3},
  pages={iyab229},
  year={2022},
  publisher={Oxford University Press}
}

@article{kelleher2016efficient,
  title={Efficient coalescent simulation and genealogical analysis for large sample sizes},
  author={Kelleher, Jerome and Etheridge, Alison M and McVean, Gilean},
  journal={PLoS computational biology},
  volume={12},
  number={5},
  pages={e1004842},
  year={2016},
  publisher={Public Library of Science}
}

@article{nelson2020accounting,
  title={Accounting for long-range correlations in genome-wide simulations of large cohorts},
  author={Nelson, Dominic and Kelleher, Jerome and Ragsdale, Aaron P and
    Moreau, Claudia and McVean, Gil and Gravel, Simon},
  journal={PLoS genetics},
  volume={16},
  number={5},
  pages={e1008619},
  year={2020},
  publisher={Public Library of Science}
}

@article{anderson2023genes,
  title={On the genes, genealogies, and geographies of Quebec},
  author={Anderson-Trocm{\'e}, Luke and Nelson, Dominic and Zabad, Shadi and Diaz-Papkovich, Alex and Kryukov, Ivan
     and Baya, Nikolas and Touvier, Mathilde and Jeffery, Ben and Dina, Christian
     and V{\'e}zina, H{\'e}l{\`e}ne and others},
  journal={Science},
  volume={380},
  number={6647},
  pages={849--855},
  year={2023},
  publisher={American Association for the Advancement of Science}
}
```
